@@ -21,7 +21,7 @@ class ConfigurationBase(type):
     def __new__(cls, name, bases, attrs):
         # also check for "Configuration" here to handle the Settings class
         # below remove it when we deprecate the Settings class
-        if (bases != (object,) and
+        if (bases not in ((object,), ()) and
                 bases[0].__name__ not in ('NewBase', 'Configuration')):
             # if this is actually a subclass in a settings module
             # we better check if the importer was correctly installed
